==> opie.i18n_anoncvs.handhelds.org_v1_2_1_.tar.gz: i18n/ru/security.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>LoginBase</name>
    <message>
        <source>LoginBase</source>
        <translation>ЛогинБаза</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Войти</translation>
    </message>
    <message>
        <source>Login Automatically</source>
        <translation>Входить автоматически</translation>
    </message>
    <message>
        <source>If you select this option, opie-login will automagically log you in with the user you have selected in the drop-down list.  

For the Zaurus 5x00 this is always the user &quot;root&quot;.</source>
        <translation>Если вы выберите эту опцию, opie-login автоматически войдет в систему под выбранным из списка пользователем.  

На Zaurus 5x00 это всегда пользователь &quot;root&quot;.</translation>
    </message>
    <message>
        <source>This drop-down list allows you to select the user for auto-login
(if enabled above).  

You can only select an actually configured user.</source>
        <translation>Этот список позволит выбрать пользователя для авто-входа
(если разрешен).  

Вы можете выбрать только уже настроенное имя пользователя.</translation>
    </message>
</context>
<context>
    <name>MultiauthConfig</name>
    <message>
        <source>Security configuration</source>
        <translation>Настройки безопасности</translation>
    </message>
    <message>
        <source>Load which plugins in what order:</source>
        <translation>Загрузить плагины в следующем порядке:</translation>
    </message>
    <message>
        <source>Check a checkbox to activate/deactivate a plugin or use the arrow buttons on the right to change the order they will appear in</source>
        <translation>Поставьте флажок чтобы активировать плагин или используйте стрелки справа чтобы изменить порядок, в котором они будут показаны</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Выше</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Ниже</translation>
    </message>
    <message>
        <source>plugins</source>
        <translation>плагины</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Войти</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхр.</translation>
    </message>
    <message>
        <source>Attention</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Любой</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ни одного</translation>
    </message>
    <message>
        <source>Important notice</source>
        <translation>Важное замечание</translation>
    </message>
    <message>
        <source>Locking</source>
        <translation>Блокировка</translation>
    </message>
    <message>
        <source>All user-defined net ranges will be lost.</source>
        <translation>Все заданные пользователем участки будут потеряны.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>To be able to protect your PDA with one or more authentication plugins (for example, a simple PIN authentication), you must install at least one &lt;em&gt;opie-securityplugin-*&lt;/em&gt; package! Once you have done that, you will be able to configure your PDA protection here.</source>
        <translation>Чтобы защитить ваш КПК одним или более плагином аутентификации (например, простой ввод ПИН), вы должны установить хотя бы один &lt;em&gt;opie-securityplugin-*&lt;/em&gt; пакет! Как только вы это сделаете, здесь вы сможете настроить защиту вашего КПК.</translation>
    </message>
</context>
<context>
    <name>MultiauthGeneralConfig</name>
    <message>
        <source>When to lock Opie</source>
        <translation>Когда заблокировать Opie</translation>
    </message>
    <message>
        <source>on Opie start</source>
        <translation>при запуске Opie</translation>
    </message>
    <message>
        <source>on Opie resume</source>
        <translation>при включении Opie</translation>
    </message>
    <message>
        <source>Multiple plugins authentication</source>
        <translation>Аутентификация со множественными плагинами</translation>
    </message>
    <message>
        <source>Required successes</source>
        <translation>Необходимо успешных</translation>
    </message>
    <message>
        <source>Don&apos;t protect this config screen</source>
        <translation>Не блокировать этот экран настройки</translation>
    </message>
    <message>
        <source>Show explanatory screens</source>
        <translation>Показывать объяснительные экраны</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Testing</source>
        <translation>Проверка</translation>
    </message>
    <message>
        <source>Test the authentication now</source>
        <translation>Проверить аутентификацию</translation>
    </message>
    <message>
        <source>Attention</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <source>You must save your current settings before trying to authenticate. Press OK to accept and launch a simulated authentication process.</source>
        <translation>Сначала вы должны сохранить текущие настройки. Нажмите &quot;Да&quot;, чтобы принять и запустить демонстрацию процесса аутентификации.</translation>
    </message>
    <message>
        <source>If you don&apos;t like the result of this test, don&apos;t forget to change your settings before you exit the configuration application!</source>
        <translation>Если вам не нравится результат этой проверки, не забудьте изменить настройки до выхода из приложения!</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Да</translation>
    </message>
</context>
<context>
    <name>SyncBase</name>
    <message>
        <source>SyncBase</source>
        <translation>СинхБаза</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхр.</translation>
    </message>
    <message>
        <source>Accept sync from network:</source>
        <translation>Принимать запросы из сети:</translation>
    </message>
    <message>
        <source>Select a net-range or enter a new one.  

This drop-down list lets you select a net range which is allowed to connect to your Zaurus.  

For example, a net range of 192.168.1.0/24 will allow any machine with an IP between 192.168.1.1 and 192.168.1.254 to connect to (and sync with) your Zaurus.  

The entry &quot;All&quot; will allow *any* IP to connect. 
The entry &quot;None&quot; will *deny* any connection.  

If unsure, select &quot;Any&quot;.</source>
        <translation>Выберите или введите новый участок сети.  

Этот список позволяет выбрать участок сети из которого можно подключится к вашему КПК.  

Например, участок сети 192.168.1.0/24 позволит любой машине с IP между 192.168.1.1 и 192.168.1.254 подключаться к (и синхронизироваться с) вашим КПК.  

Запись &quot;Все&quot; позволит подключиться *любому* IP. 
Запись &quot;Ни одного&quot; *запретит* все соединения.  

Если неуверены, выберите &quot;Все&quot;.</translation>
    </message>
    <message>
        <source>Delete Entry</source>
        <translation>Удалить запись</translation>
    </message>
    <message>
        <source>Delete the selected net range from the list

If you press this button, the currently selected net range will be deleted from the list of net ranges.

If you hit this button in error, the button &quot;Restore Defaults&quot; will restore
the list to the state it has been when you initially booted your Zaurus.</source>
        <translation>Удалить выбранный участок из списка

Если вы нажмете эту кнопку, выбранный участок будет удален из списка.

Если вы нажали эту кнопку случайно, кнопка &quot;По умолчанию&quot;
восстановит список в том виде, когда вы первый раз запустили ваш КПК.</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>This button will restore the list of net ranges
to the defaults.

Beware that all manually entered net ranges will be lost!</source>
        <translation>Эта кнопка восстановит список участков сети
по умолчанию.

Учтите что вручную введенные участки будут потеряны!</translation>
    </message>
    <message>
        <source>Select your sync software</source>
        <translation>Выберите программу</translation>
    </message>
    <message>
        <source>Qtopia 1.7</source>
        <translation>Qtopia 1.7</translation>
    </message>
    <message>
        <source>Opie 1.0</source>
        <translation>Opie 1.0</translation>
    </message>
    <message>
        <source>IntelliSync</source>
        <translation>IntelliSync</translation>
    </message>
    <message>
        <source>Alter the Sync Protocol to tweak for the different devices.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    IntelliSync will disable the password check but you&apos;ll be prompted to accept the connection.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    Opie1.0 will be compatible with QtopiaDesktop, MultiSync and KitchenSync
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    Qtopia1.7 will alter the way data is send to the client and will not work with older clients.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/></source>
        <translation type="obsolete">Изменить протокол синхронизации для разных устройств.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    IntelliSync запретит проверку пароля но будет запрашивать подтверждение на прием соединения.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    Opie1.0 совместим с QtopiaDesktop, MultiSync и KitchenSync
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    Qtopia1.7 изменит способ пересылки данных клиенту и не будет работать со старыми клиентами.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/></translation>
    </message>
    <message>
        <source>Alter the Sync Protocol to tweak for the different devices.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    IntelliSync will disable the password check but you&apos;ll be prompted to accept the connection.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    Opie1.0 will be compatible with QtopiaDesktop, MultiSync and KitchenSync
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    Qtopia1.7 will alter the way data is send to the client and will not work with older clients.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    </source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> opie.i18n_anoncvs.handhelds.org_v1_2_3_.tar.gz: i18n/ru/security.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>LoginBase</name>
    <message>
        <source>LoginBase</source>
        <translation>ЛогинБаза</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Войти</translation>
    </message>
    <message>
        <source>Login Automatically</source>
        <translation>Входить автоматически</translation>
    </message>
    <message>
        <source>If you select this option, opie-login will automagically log you in with the user you have selected in the drop-down list.  

For the Zaurus 5x00 this is always the user &quot;root&quot;.</source>
        <translation>Если вы выберите эту опцию, opie-login автоматически войдет в систему под выбранным из списка пользователем.  

На Zaurus 5x00 это всегда пользователь &quot;root&quot;.</translation>
    </message>
    <message>
        <source>This drop-down list allows you to select the user for auto-login
(if enabled above).  

You can only select an actually configured user.</source>
        <translation>Этот список позволит выбрать пользователя для авто-входа
(если разрешен).  

Вы можете выбрать только уже настроенное имя пользователя.</translation>
    </message>
</context>
<context>
    <name>MultiauthConfig</name>
    <message>
        <source>Security configuration</source>
        <translation>Настройки безопасности</translation>
    </message>
    <message>
        <source>Load which plugins in what order:</source>
        <translation>Загрузить плагины в следующем порядке:</translation>
    </message>
    <message>
        <source>Check a checkbox to activate/deactivate a plugin or use the arrow buttons on the right to change the order they will appear in</source>
        <translation>Поставьте флажок чтобы активировать плагин или используйте стрелки справа чтобы изменить порядок, в котором они будут показаны</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Выше</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Ниже</translation>
    </message>
    <message>
        <source>plugins</source>
        <translation>плагины</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Аутентификация</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Войти</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхр.</translation>
    </message>
    <message>
        <source>Attention</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Любой</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ни одного</translation>
    </message>
    <message>
        <source>Important notice</source>
        <translation>Важное замечание</translation>
    </message>
    <message>
        <source>Locking</source>
        <translation>Блокировка</translation>
    </message>
    <message>
        <source>All user-defined net ranges will be lost.</source>
        <translation>Все заданные пользователем участки будут потеряны.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Да</translation>
    </message>
    <message>
        <source>To be able to protect your PDA with one or more authentication plugins (for example, a simple PIN authentication), you must install at least one &lt;em&gt;opie-securityplugin-*&lt;/em&gt; package! Once you have done that, you will be able to configure your PDA protection here.</source>
        <translation>Чтобы защитить ваш КПК одним или более плагином аутентификации (например, простой ввод ПИН), вы должны установить хотя бы один &lt;em&gt;opie-securityplugin-*&lt;/em&gt; пакет! Как только вы это сделаете, здесь вы сможете настроить защиту вашего КПК.</translation>
    </message>
</context>
<context>
    <name>MultiauthGeneralConfig</name>
    <message>
        <source>When to lock Opie</source>
        <translation>Когда заблокировать Opie</translation>
    </message>
    <message>
        <source>on Opie start</source>
        <translation>при запуске Opie</translation>
    </message>
    <message>
        <source>on Opie resume</source>
        <translation>при включении Opie</translation>
    </message>
    <message>
        <source>Multiple plugins authentication</source>
        <translation>Аутентификация со множественными плагинами</translation>
    </message>
    <message>
        <source>Required successes</source>
        <translation>Необходимо успешных</translation>
    </message>
    <message>
        <source>Don&apos;t protect this config screen</source>
        <translation>Не блокировать этот экран настройки</translation>
    </message>
    <message>
        <source>Show explanatory screens</source>
        <translation>Показывать объяснительные экраны</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Опции</translation>
    </message>
    <message>
        <source>Testing</source>
        <translation>Проверка</translation>
    </message>
    <message>
        <source>Test the authentication now</source>
        <translation>Проверить аутентификацию</translation>
    </message>
    <message>
        <source>Attention</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <source>You must save your current settings before trying to authenticate. Press OK to accept and launch a simulated authentication process.</source>
        <translation>Сначала вы должны сохранить текущие настройки. Нажмите &quot;Да&quot;, чтобы принять и запустить демонстрацию процесса аутентификации.</translation>
    </message>
    <message>
        <source>If you don&apos;t like the result of this test, don&apos;t forget to change your settings before you exit the configuration application!</source>
        <translation>Если вам не нравится результат этой проверки, не забудьте изменить настройки до выхода из приложения!</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Да</translation>
    </message>
</context>
<context>
    <name>SyncBase</name>
    <message>
        <source>SyncBase</source>
        <translation>СинхБаза</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхр.</translation>
    </message>
    <message>
        <source>Accept sync from network:</source>
        <translation>Принимать запросы из сети:</translation>
    </message>
    <message>
        <source>Select a net-range or enter a new one.  

This drop-down list lets you select a net range which is allowed to connect to your Zaurus.  

For example, a net range of 192.168.1.0/24 will allow any machine with an IP between 192.168.1.1 and 192.168.1.254 to connect to (and sync with) your Zaurus.  

The entry &quot;All&quot; will allow *any* IP to connect. 
The entry &quot;None&quot; will *deny* any connection.  

If unsure, select &quot;Any&quot;.</source>
        <translation>Выберите или введите новый участок сети.  

Этот список позволяет выбрать участок сети из которого можно подключится к вашему КПК.  

Например, участок сети 192.168.1.0/24 позволит любой машине с IP между 192.168.1.1 и 192.168.1.254 подключаться к (и синхронизироваться с) вашим КПК.  

Запись &quot;Все&quot; позволит подключиться *любому* IP. 
Запись &quot;Ни одного&quot; *запретит* все соединения.  

Если неуверены, выберите &quot;Все&quot;.</translation>
    </message>
    <message>
        <source>Delete Entry</source>
        <translation>Удалить запись</translation>
    </message>
    <message>
        <source>Delete the selected net range from the list

If you press this button, the currently selected net range will be deleted from the list of net ranges.

If you hit this button in error, the button &quot;Restore Defaults&quot; will restore
the list to the state it has been when you initially booted your Zaurus.</source>
        <translation>Удалить выбранный участок из списка

Если вы нажмете эту кнопку, выбранный участок будет удален из списка.

Если вы нажали эту кнопку случайно, кнопка &quot;По умолчанию&quot;
восстановит список в том виде, когда вы первый раз запустили ваш КПК.</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>This button will restore the list of net ranges
to the defaults.

Beware that all manually entered net ranges will be lost!</source>
        <translation>Эта кнопка восстановит список участков сети
по умолчанию.

Учтите что вручную введенные участки будут потеряны!</translation>
    </message>
    <message>
        <source>Select your sync software</source>
        <translation>Выберите программу</translation>
    </message>
    <message>
        <source>Qtopia 1.7</source>
        <translation>Qtopia 1.7</translation>
    </message>
    <message>
        <source>Opie 1.0</source>
        <translation>Opie 1.0</translation>
    </message>
    <message>
        <source>IntelliSync</source>
        <translation>IntelliSync</translation>
    </message>
    <message>
        <source>Alter the Sync Protocol to tweak for the different devices.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    IntelliSync will disable the password check but you&apos;ll be prompted to accept the connection.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    Opie1.0 will be compatible with QtopiaDesktop, MultiSync and KitchenSync
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    Qtopia1.7 will alter the way data is send to the client and will not work with older clients.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/></source>
        <translation>Изменить протокол синхронизации под разные устройства.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    IntelliSync отключит проверку пароля, но будет запрашивать подтверждение при каждом соединении.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    Opie1.0 будет совместим с QtopiaDesktop, MultiSync и KitchenSync
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/>    Qtopia1.7 изменит способ передачи данных и не будет работать со старыми клиентами.
<byte value="x9"/><byte value="x9"/><byte value="x9"/><byte value="x9"/></translation>
    </message>
</context>
</TS>
